Release History
===============

0.2.3 - September 26, 2013
--------------------------

 * Added ability to generate coverage

 * Integration with Duvet

0.2.2 - September 17, 2013
--------------------------

 * Corrected a problem with starting unittest2 projects.

 * Corrected a error raised when unittest2 was manually installed in
   PYTHONPATH.

0.2.1 - September 14, 2013
--------------------------

 * Fixed selection of test modules in unittest2-style suite discovery.

 * Added ability to run Django's own test suite.

0.2.0 - August 31, 2013
-----------------------

 * Relaunch as a PyBee project.

 * Added test and help menus.

0.1.3 - July 29, 2013
---------------------

 * Corrected problem with Django test executor, masked by pyc caching.

 * Improved collection of errors raised during test startup.

0.1.2 - July 26, 2013
---------------------

 * Improved handling of button state during test execution.

0.1.1 - July 9, 2013
--------------------

Release incorporating updates from the PyCon AU 2013 sprints, including:

 * Unittest2 support

 * Improved handling of errors raised during test execution

 * Improved reporting of errors caused on Ubuntu

0.1.0 - June 21, 2013
---------------------

Initial public release, at PyCon AU 2013
